Summary:        Set of open source libraries enabling integration of the SCAP line of standards
Name:           openscap
Version:        1.3.10
Release:        1%{?dist}
License:        LGPLv2+
URL:            http://www.open-scap.org/
Source0:        https://github.com/OpenSCAP/openscap/releases/download/%{version}/openscap-%{version}.tar.gz

BuildRequires:  make cmake >= 2.6 gcc gcc-c++ swig 
BuildRequires:  libxml2-devel libxslt-devel perl-generators perl-XML-Parser
BuildRequires:  rpm-devel libgcrypt-devel pcre-devel libacl-devel
BuildRequires:  libselinux-devel libcap-devel libblkid-devel
BuildRequires:  bzip2-devel asciidoc openldap-devel
BuildRequires:  glib2-devel dbus-devel libyaml-devel
BuildRequires:  xmlsec1-devel xmlsec1-openssl-devel

Requires:       bash bzip2-libs dbus glib2 libacl
Requires:       libblkid libcap libselinux openldap popt
Requires:       procps xmlsec1 xmlsec1-openssl

%description
The oscap program is a command line tool that allows users to load, scan, validate, edit, and export SCAP documents.

%package        utils
Summary:        OpenSCAP Utilities
Requires:       openscap = %{version}-%{release}
Requires:       rpmdevtools rpm-build openscap-scanner = %{version}-%{release}

%description    utils
The openscap-utils package contains command-line tools build on top
of OpenSCAP library.

%package        devel
Summary:        Development files for openscap
Requires:       openscap = %{version}-%{release} libxml2-devel pkgconfig

%description    devel
The openscap-devel package contains libraries and header files for
developing applications that use openscap.

%package        scanner
Summary:        OpenSCAP Scanner Tool (oscap)
BuildRequires:  libcurl-devel >= 7.12.0
Requires:       openscap = %{version}-%{release} libcurl >= 7.12.0

%description    scanner
The openscap-scanner package contains oscap ,which is a 
configuration and vulnerability scanner, can perform compliance 
checking using SCAP content.

%package        engine-sce
Summary:        Script Check Engine plug-in for OpenSCAP
Requires:       openscap = %{version}-%{release}

%description    engine-sce
The Script Check Engine is non-standard extension to SCAP protocol. This
engine allows content authors to avoid OVAL language and write their assessment
commands using a scripting language (Bash, Perl, Python, Ruby, ...).

%package        engine-sce-devel
Summary:        Development files for openscap-engine-sce
Requires:       openscap-devel = %{version}-%{release}
Requires:       openscap-engine-sce = %{version}-%{release} pkgconfig

%description    engine-sce-devel
The openscap-engine-sce-devel package contains libraries and header files
for developing applications that use openscap-engine-sce.

%package        containers
Summary:        Utils for scanning containers
Requires:       openscap = %{version}-%{release} openscap-scanner
BuildArch:      noarch

%description    containers
Tool for scanning Atomic containers.

%package        python3
Summary:        Python 3 bindings for openscap
BuildRequires:  python3-devel
Requires:       openscap = %{version}-%{release}

%description    python3
The openscap-python3 package contains the bindings so that openscap
libraries can be used by python3.

%prep
%autosetup -p1

%build
%cmake -DENABLE_PERL=OFF -DOPENSCAP_PROBE_UNIX_GCONF=OFF -DGCONF_LIBRARY=
%cmake_build
%check

%install
%cmake_install

find %{buildroot} -name '*.la' -delete

pathfix.py -i %{__python3} -p -n %{buildroot}%{_bindir}/scap-as-rpm

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/libopenscap.so.*
%dir %{_datadir}/openscap
%dir %{_datadir}/openscap/schemas
%dir %{_datadir}/openscap/xsl
%dir %{_datadir}/openscap/cpe
%{_datadir}/openscap/schemas/*
%{_datadir}/openscap/xsl/*
%{_datadir}/openscap/cpe/*

%files utils
%doc docs/oscap-scan.cron
%{_bindir}/*
%exclude %{_bindir}/oscap
%exclude %{_bindir}/oscap-docker
%exclude %{_bindir}/oscap-chroot
%{_mandir}/man8/*
%exclude %{_mandir}/man8/oscap.8*
%exclude %{_mandir}/man8/oscap-docker.8*

%files devel
%{_libdir}/libopenscap.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/openscap
%exclude %{_includedir}/openscap/sce_engine_api.h

%files scanner
%{_bindir}/oscap
%{_bindir}/oscap-chroot
%{_sysconfdir}/bash_completion.d
%{_mandir}/man8/oscap.8*


%files engine-sce
%{_libdir}/libopenscap_sce.so.*

%files engine-sce-devel
%{_libdir}/libopenscap_sce.so
%{_includedir}/openscap/sce_engine_api.h


%files containers
%{_bindir}/oscap-docker
%{_bindir}/oscap-podman
%{python3_sitelib}/oscap_docker_python/*
%{_mandir}/man8/oscap-podman.8*
%{_mandir}/man8/oscap-docker.8*

%files python3
%{python3_sitearch}/*

%changelog
* Fri Jul 19 2024 Upgrade Robot <upbot@opencloudos.tech> - 1.3.10-1
- Upgrade to version 1.3.10

* Thu Oct 12 2023 Miaojun Dong <zoedong@tencent.com> - 1.3.8-5
- Rebuild for curl-8.4.0

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.8-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.8-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 18 2023 Wang Guodong <gordonwwang@tencent.com> - 1.3.8-2
- Rebuilt for xmlsec1 1.2.38

* Wed Jul 12 2023 Shuo Wang <abushwang@tencent.com> - 1.3.8-1
- update to 1.3.8

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.6-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.3.6-3
- Rebuilt for OpenCloudOS Stream 23

* Thu Dec 8 2022 Feng Weiyao <wynnfeng@tencent.com> - 1.3.6-2
- fix mail errors in changelog.

* Wed Sep 7 2022 Feng Weiyao <wynnfeng@tencent.com> - 1.3.6-1
- package init.
